#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 basic-prelude
version:              0.7.0
visibility:           public
id:                   basic-prelude-0.7.0-K6xaiXTxmua20czygGMkZv
key:                  basic-prelude-0.7.0-K6xaiXTxmua20czygGMkZv
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Dan Burton
homepage:             https://github.com/snoyberg/basic-prelude#readme
synopsis:
    An enhanced core prelude; a common foundation for alternate preludes.

description:
    Please see the README on Github at <https://github.com/snoyberg/basic-prelude#readme>

category:             Control, Prelude
abi:                  6c9688b62b549b5f1643d63d42ae8d72
exposed:              True
exposed-modules:      BasicPrelude CorePrelude
hidden-modules:       Paths_basic_prelude
import-dirs:          /usr/lib/ghc-9.6.6/site-local/basic-prelude-0.7.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/basic-prelude-0.7.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/basic-prelude-0.7.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-basic-prelude
hs-libraries:         HSbasic-prelude-0.7.0-K6xaiXTxmua20czygGMkZv
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    filepath-1.4.300.1 hashable-1.4.7.0-8qGpYVybfmaKH8giGSMaAG
    text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-9qHVoc2smYt9flJ6feRxGY
    vector-0.13.2.0-AWRowWUrdYO1choGzrrEgg

haddock-interfaces:
    /usr/share/doc/haskell-basic-prelude/html/basic-prelude.haddock

haddock-html:         /usr/share/doc/haskell-basic-prelude/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

